/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Interface:  AdvancedOptionsAction.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;

/**
 * Action used for an application level options menu item. Specifically,
 * <code>Options->MetamorphoSys Options</code>.
 * 
 * @author Deborah Shapiro
 * @see AdvancedOptionsGUI
 */
public class AdvancedOptionsAction extends AbstractAction {

  //
  // Private Field
  //
  UserConfiguration config = null;

  //
  // Constructor
  //

  /**
   * Instantiates an action for the <code>Options->MetamorphoSys Options</code>
   * menu.
   * 
   * @param config
   *          the {@link UserConfiguration}
   */
  public AdvancedOptionsAction(UserConfiguration config) {
    super();

    // configure action
    this.config = config;
    putValue(Action.NAME, "MetamorphoSys Options");
    putValue(Action.SHORT_DESCRIPTION, "Configure application level options");
    setEnabled(true);
  }

  //
  // Methods
  //

  /**
   * Opens an {@link AdvancedOptionsGUI} to configure the
   * {@link UserConfiguration}.
   * 
   * @param e
   *          an {@link java.awt.event.ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    (new AdvancedOptionsGUI(config)).setVisible(true);
  }
}
