/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Interface:  Configurable.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;

import java.util.Properties;

/**
 * Generically represents an object that can be configured by the
 * {@link MetamorphoSys} application.
 *
 * @author Deborah Shapiro
 *
 **/

public interface Configurable {

  //
  // Methods
  //
  /**
   * Method provides the filter with values from the default configuration
   * file.
   * @param c {@link ApplicationConfiguration}
   */
  public void setConfiguration(ApplicationConfiguration c);

  /**
   * Method provides the filter with values from the user configuration
   * file.
   * @param c {@link UserConfiguration}
   */
  public void setConfiguration(UserConfiguration c);

  /**
   * Method returns a {@link String} detailing
   * the user selections on the filter.  This {@link String} will
   * be displayed in the mmsys.log at the completion of subsetting
   * so it should be formatted to be easily read.
   * @return {@link String} of data for log
   */
  public String getConfigurationDetails();

  /**
   * Returns the {@link Properties} representing the configuration choices.
   * @return the {@link Properties} representing the configuration choices
   */
  public Properties getProperties();

  /**
   * Sets the {@link Properties} representing the configuration choices.
   * @param p the {@link Properties} representing the configuration choices
   */
  public void setProperties(Properties p);

  /**
   * Resets the configuration back to default values. When used with a GUI
   * this method should change the data model behind the GUI and allow
   * <code>setPanelSelections</code> to actually update the GUI.
   */
  public void resetToDefaults();

}

