/**************************************************************************
 *
 * Package:     gov.nih.nlm.mms
 * Interface:   CuiList.java
 *
 **************************************************************************/
package gov.nih.nlm.mms;

import gov.nih.nlm.umls.meta.Concept;

/**
 * This class is used during the first phase of {@link MetamorphoSys}
 * subsetting, in which a list of cuis to be kept is built up.
 * The class is designed to minimize the memory impact of keeping
 * track of the cuis.
 *
 * @author Deborah Shapiro, Brian Carlsen
 */
public interface CuiList {

  //
  // Methods
  //
  /**
   * Returns <code>true</code> if any part of the {@link Concept} being kept.
   * @param cui a {@link String} cui value
   * @return <code>true</code> if any part of the {@link Concept} being kept
   */
  public boolean inList(String cui);

  /**
   * Enables a filter to specify a Cui should be added to the cui list.
   * @param cui {@link String}
   */
  public void addCui(String cui);

  /**
   * Indicates that cui was added by the user and not just left
   * through filtering process.
   * @param cui {@link String}
   * @return <code>boolean</code>
   */
  public boolean addedByUserOnly(String cui);

  /**
   * Enables a filter to specify a Cui that should be removed from the
   * cui list.
   * @param cui {@link String}
   */
  public void removeCui(String cui);

}
