/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Object:     EnableFilterRedoHandler.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;

import gov.nih.nlm.mms.filters.Filter;

import java.util.List;

/**
 * Handles the redo operation for an enable or disable filter action.
 *
 * @author Deborah Shapiro
 **/
public class EnableFilterRedoHandler implements RedoHandler{

  //
  // Fields
  //
  private MetamorphoSysGUI gui = null;

  /**
   * Instantiates an {@link EnableFilterRedoHandler} for the specified gui.
   * @param gui the {@link MetamorphoSysGUI}
   */
  public EnableFilterRedoHandler(MetamorphoSysGUI gui) {
    this.gui = gui;
  }

  //
  // Methods
  //

  /**
   * Returns the title for the redo menu item.
   * @return the title for the redo menu item
   */
  public String getTitle() {
    return "Redo Enable Filter";
  }

  /**
   * Performs the redo operation and prepares the undo stack.
   * @param o1 the previous set of active filters
   * @param o2 the current set of active filters
   */
  public void redo(Object o1, Object o2) {

    //
    // Get previous set of active filters
    //
    List active_filters_before = (List)o2;

    //
    // Clear active filter list
    //
    UserConfiguration uc = gui.getUserConfiguration();
    uc.clearFilters();

    //
    // Enable new filters
    //
    List valid_filters = uc.getValidFilters();
    for (int i = 0; i < valid_filters.size(); i++) {
      if (active_filters_before.contains(valid_filters.get(i)))
        uc.enableFilter((Filter)(valid_filters.get(i)));
    }

    //
    // Remove tabs for filters no longer active
    //
    List active_filters_after = (List)o1;
    for (int i = 0; i < active_filters_after.size(); i++) {
      Filter filter = (Filter) active_filters_after.get(i);
      if (!active_filters_before.contains(filter))
        gui.removeTab(filter);
    }

    //
    // Add tabs for new filters
    //
    for (int i = 0; i < active_filters_before.size(); i++) {
      Filter filter = (Filter) active_filters_before.get(i);
      if (!active_filters_after.contains(filter)) {
        gui.initializeGUIConfigurable(filter);
      }
    }

    //
    // Prep the undo stack
    //
    Object[] undo_tuple = {new EnableFilterUndoHandler(gui), o1, o2};
    gui.pushOnUndoStack(undo_tuple);

  }

}