/**************************************************************************
 *
 * Package:	gov.nih.nlm.mms
 * Object:	MetamorphoSysWebStart.java
 *
 **************************************************************************/
package gov.nih.nlm.mms;

import gov.nih.nlm.util.ClasspathToolkit;

import java.io.File;
import java.io.InputStream;
import java.util.Properties;

/**
 * Java Web Start Launcher.
 *
 * @author Deborah Shapiro
 */
public class MetamorphoSysWebStart  {


  //
  // Main
  //

  /**
   * Standard Application entry point.
   * Running this main method will present the user with
   * a GUI frame for configuring the subsetting operations.
   * @param args {@link String}[]
   */
  public static void main(String[] args) {
    MetamorphoSys metamorphosys = null;
    try {
      // Instantiate Application
      MMSToolkit.setUsingView(true);

      ClasspathToolkit.setSystemClasspathForJWS(MetamorphoSys.class);

      if (args.length == 2) {
        Properties ac_props = new Properties();
        ac_props.load((InputStream)MetamorphoSys.class.getClassLoader().getResource(
          "config/mmsys.a.prop").getContent());
        ApplicationConfiguration ac = new ApplicationConfiguration(ac_props);

        Properties uc_props = new Properties();
        uc_props.load((InputStream)MetamorphoSys.class.getClassLoader().getResource(
          "config/mmsys.prop.sav").getContent());
        UserConfiguration uc = new UserConfiguration(uc_props);

        // set install & subset dirs
        uc.clearSourcePaths();
        uc.addSourcePath(args[0]);
        uc.setSubsetDirectory(args[1]);
        metamorphosys = new MetamorphoSys(ac, uc);

        metamorphosys.subset();
      } else if (new File("config/mmsys.prop.sav").exists()) {
        metamorphosys = new MetamorphoSys();
      } else {
        Properties ac_props = new Properties();
        ac_props.load((InputStream)MetamorphoSys.class.getClassLoader().getResource(
          "config/mmsys.a.prop").getContent());
        ApplicationConfiguration ac = new ApplicationConfiguration(ac_props);

        Properties uc_props = new Properties();
        uc_props.load((InputStream)MetamorphoSys.class.getClassLoader().getResource(
          "config/mmsys.prop.sav").getContent());
        UserConfiguration uc = new UserConfiguration(uc_props);

        metamorphosys = new MetamorphoSys(ac, uc);
      }
    } catch (Exception e) {
      e.printStackTrace();
      try { metamorphosys.getUserConfiguration().getInputStream().close(); } catch (Exception ex) {}
      MMSToolkit.reportError("Radically unexpected error.  \nPlease see console. \n\n" + e.getMessage(), true);
    }

    MMSToolkit.Exit(0);
  }

}
