/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Object:     OutputStreamRedoHandler.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;

import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * Handles redo operation for a change in output handler.
 */
public class OutputStreamRedoHandler implements RedoHandler{

  //
  // Fields
  //
  private MetamorphoSysGUI gui = null;
  private JTextField field = null;
  private JPanel content_panel = null;

  /**
   * Instantiates an {@link OutputStreamRedoHandler}.
   * @param gui the {@link MetamorphoSysGUI}
   * @param field the text field to update
   * @param content_panel the panel to update
   */
  public OutputStreamRedoHandler(MetamorphoSysGUI gui,
                                JTextField field,
                                JPanel content_panel) {
    this.gui = gui;
    this.field = field;
    this.content_panel = content_panel;
  }

  //
  // Methods
  //

  /**
   * Returns the title for the redo menu.
   * @return the title for the rndo menu
   */
  public String getTitle() {
    return "Redo change output format";
  }

  /**
   * Performs the redo operation.
   * @param o1 the new output stream
   * @param o2 the old output stream
   */
  public void redo(Object o1, Object o2) {
    //
    // Change output stream back
    //
    gui.changeOutputStream(((MetamorphoSysOutputStream)o1),
                          field, content_panel);

    gui.selectTabForFilter((MetamorphoSysOutputStream)o1);

    //
    // Push onto undo stack
    //
    Object[] tuple =
        {new OutputStreamUndoHandler(gui,
                                   field, content_panel),
         o1, o2};
     gui.pushOnUndoStack(tuple);
  }

}
