/*****************************************************************************
 *
 * Package: gov.nih.nlm.mms
 * Object: RedoAction.java
 *
 *****************************************************************************/
package gov.nih.nlm.mms;

import java.awt.Event;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.KeyStroke;

/**
 * Re-performs an undone action. Used for the <code>Edit->Redo</code> menu of
 * {@link MetamorphoSysGUI}.
 * 
 * @author Brian Carlsen, Deborah Shapiro
 */
public class RedoAction extends AbstractAction {

  //
  // Private Fields
  //
  MetamorphoSysGUI gui;

  /**
   * Instantiates a {@link RedoAction}.
   * 
   * @param gui
   *          the {@link MetamorphoSysGUI}
   */
  public RedoAction(MetamorphoSysGUI gui) {
    super();
    this.gui = gui;

    // configure action
    putValue(Action.NAME, "Redo");
    putValue(Action.SHORT_DESCRIPTION, "Redo");
    putValue(Action.MNEMONIC_KEY, new Integer((int) 'y'));
    putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Y',
        Event.CTRL_MASK));
  }

  /**
   * Pops an item off of the redo stack, makes the necessary changes, and pushes
   * an item onto the undo stack.
   * 
   * @param e
   *          an {@link ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    Object[] tuple = gui.popOffRedoStack();
    ((RedoHandler) tuple[0]).redo(tuple[1], tuple[2]);
  }

}
