/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Interface:  SubsetListener.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;


/**
 * Generically represents a listener interested in  different phases of
 * the subsetting process.  Also provides a reference to the {@link CuiList}.
 *
 * @author Deborah Shapiro
 *
 **/

public interface SubsetListener {

  //
  // Methods
  //
  /**
   * Provides filter access to the cui list.
   * @param cui_list {@link CuiList}
   */
  public void setCuiList(CuiList cui_list);

  /**
   * Informs filter that the Initialize Cui List phase is starting.
   */
  public void beginInitializeCuiList();

  /**
   * Informs filter that the Initialize Cui List phase is ending.
   */
  public void endInitializeCuiList();

  /**
   * Informs filter that the Subset Content phase is starting.
   */
  public void beginSubsetContent();

  /**
   * Informs filter that the Subset Content phase is ending.
   */
  public void endSubsetContent();

}

