/*****************************************************************************
 * Package: gov.nih.nlm.mms
 * Object:  UndoAction.java
 *
 *****************************************************************************/
package gov.nih.nlm.mms;

import java.awt.Event;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.KeyStroke;

/**
 * Unperforms an action. Used for the <code>Edit->Undo</code> Menu of
 * {@link MetamorphoSysGUI}.
 * 
 * @author Brian Carlsen, Deborah Shapiro
 */
public class UndoAction extends AbstractAction {

  //
  // Private Fields
  //
  MetamorphoSysGUI gui;

  /**
   * Instantiates an {@link UndoAction}.
   * 
   * @param gui
   *          the {@link MetamorphoSysGUI}
   */
  public UndoAction(MetamorphoSysGUI gui) {
    super();
    this.gui = gui;

    // configure action
    putValue(Action.NAME, "Undo");
    putValue(Action.SHORT_DESCRIPTION, "Undo");
    putValue(Action.MNEMONIC_KEY, new Integer((int) 'z'));
    putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Z',
        Event.CTRL_MASK));
  }

  //
  // Methods
  //

  /**
   * Pops an item off of the undo stack, makes the necessary changes, and pushes
   * an item onto the redo stack.
   * 
   * @param e
   *          an {@link ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    Object[] tuple = gui.popOffUndoStack();
    ((UndoHandler) tuple[0]).undo(tuple[1], tuple[2]);
  }

}
