/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms;
 * Interface:  WelcomeGUI.java
 *
 *************************************************************************/
package gov.nih.nlm.mms;

import gov.nih.nlm.mms.browser.RRFBrowserGUI;
import gov.nih.nlm.mms.cxt.MRCXTBuilderGUI;
import gov.nih.nlm.swing.CenteredBackgroundBorder;
import gov.nih.nlm.swing.FontSizeManager;
import gov.nih.nlm.swing.GlassComponent;
import gov.nih.nlm.swing.GlassPaneListener;
import gov.nih.nlm.swing.SwingToolkit;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.image.BufferedImage;
import java.io.File;
import java.net.URL;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JTextPane;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;

/**
 * Application entry point for GUI users. It offers two choices: Install the
 * UMLS, or subset a current Metathesaurus.
 * 
 * @author Deborah Shapiro
 */
public class WelcomeGUI extends JFrame implements GlassPaneListener {

  //
  // Fields
  //

  //
  // For glass pane
  //
  private GlassComponent gc = null;

  //
  // Static singleton instance
  //
  private static WelcomeGUI welcome_gui = null;

  //
  // Constructor
  //

  /**
   * Returns the singleton reference to the {@link WelcomeGUI}.
   * 
   * @return the singleton reference to the {@link WelcomeGUI}
   */
  public static WelcomeGUI getWelcomeGUI() {
    if (welcome_gui == null)
      welcome_gui = new WelcomeGUI();
    return welcome_gui;
  }

  /**
   * Instantiates the {@link WelcomeGUI}. The constructor does not make it
   * visible.
   */
  private WelcomeGUI() {
    super("Welcome to MetamorphoSys");

    //
    // Handle glass pane
    //
    gc = new GlassComponent(this);
    setGlassPane(gc);

    //
    // Base panel for GUI
    //
    JPanel base_panel = new JPanel(new BorderLayout());

    //
    // Compose menu bar
    //
    JMenuBar menu_bar = new JMenuBar();
    setJMenuBar(menu_bar);
    JMenu file_menu = new JMenu("File");
    menu_bar.add(file_menu);
    menu_bar.add(Box.createHorizontalGlue());
    JMenu help_menu = new JMenu("Help");
    menu_bar.add(help_menu);

    //
    // File Menu
    //
    JMenuItem copy_menu_item = new JMenuItem(new CopyToHardDriveAction());
    file_menu.add(copy_menu_item);

    JMenuItem validate_menu_item = new JMenuItem(
        new ValidateDistributionAction());
    file_menu.add(validate_menu_item);

    JMenuItem exit_menu_item = new JMenuItem("Exit");
    exit_menu_item.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        dispose();
        MMSToolkit.Exit(0);
      }
    });
    exit_menu_item.setAccelerator(KeyStroke.getKeyStroke('Q',
        java.awt.Event.CTRL_MASK, false));
    file_menu.add(exit_menu_item);

    //
    // Help Menu
    //
    buildHelpMenu(help_menu);

    //
    // NLM banner
    //
    JPanel nlm_panel = new JPanel();
    nlm_panel.setBackground(Color.white);
    ImageIcon nlm_icon = null;
    BufferedImage nlm_image = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/nlmnamelogo.gif");
      nlm_image = SwingToolkit.readScaledImage(gif_url, 325, false);
      nlm_icon = new ImageIcon(nlm_image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/nlmnamelogo.gif could not be loaded.");
    }
    int yellow_rgb = nlm_image.getRGB(155, 15);

    JLabel nlm_label = new JLabel(nlm_icon);
    nlm_label.setBorder(new EmptyBorder(5, 5, 5, 5));
    nlm_panel.add(nlm_label);
    base_panel.add(nlm_panel, BorderLayout.NORTH);

    //
    // Text and Button Panel
    //
    GridBagLayout choice_gb = new GridBagLayout();
    JPanel choice_panel = new JPanel(choice_gb);
    choice_panel.setOpaque(false);
    GridBagConstraints choice_csts = new GridBagConstraints();
    choice_csts.fill = GridBagConstraints.VERTICAL;
    Border bkgrnd = null;
    BufferedImage tree_image = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/UMLSTree.jpg");
      tree_image = SwingToolkit.readScaledImage(gif_url, 350, false);
      bkgrnd = new CenteredBackgroundBorder(tree_image);
    } catch (Exception e) {
      throw new RuntimeException(
          "Could not find resource 'config/UMLSTree.jpg'");
    }
    int rgb = tree_image.getRGB(1, 3);
    JPanel choiceicon_panel = new JPanel(new BorderLayout());
    choiceicon_panel.setBackground(new Color(rgb));
    choiceicon_panel.setBorder(bkgrnd);
    // choiceicon_panel.setPreferredSize(new Dimension(tree_image.getWidth(),
    // tree_image.getHeight()));

    //
    // MetamorphoSys Text
    //
    JTextPane text = new JTextPane();
    text.setOpaque(false);
    text.setEditable(false);

    Color yellow = new Color(yellow_rgb);
    String yellow_str = "#" + Integer.toHexString(yellow.getRed())
        + Integer.toHexString(yellow.getGreen())
        + Integer.toHexString(yellow.getBlue());
    text.setContentType("text/html");
    text
        .setText("<html><body><font style=\"font-size:20pt; font-family:serif\" color=\"#000000\">"
            + "<b><center><br>"
            + "<br><br>METAMORPHOSYS<br>THE&nbsp;UMLS&nbsp;INSTALLATION<br>TOOL</b>"
            + "</center></font></body></html>");
    choice_csts.insets = new Insets(0, 15, 30, 2);
    choice_panel.add(text, choice_csts);
    choice_csts.gridy++;

    //
    // Install UMLS Button
    //
    choice_csts.gridy++;
    JButton jinstall_umls = new JButton("Install UMLS");
    jinstall_umls.setBackground(new Color(rgb));
    jinstall_umls.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        InstallConfiguration.getInstallConfiguration().initialize();
        InstallationGUI install_gui = new InstallationGUI();
        install_gui.setVisible(true);
        MMSToolkit.fakeMRDOCSuppressRows();
      }
    });
    choice_csts.insets = new Insets(2, 2, 2, 2);
    choice_panel.add(jinstall_umls, choice_csts);

    //
    // Customize Subset Button
    //
    choice_csts.gridy++;
    JButton jrun_mmsys = new JButton("Customize my subset");
    jrun_mmsys.setBackground(new Color(rgb));
    jrun_mmsys.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        InstallConfiguration.getInstallConfiguration().initialize();
        MetamorphoSys metamorphosys = new MetamorphoSys();
        MMSToolkit.fakeMRDOCSuppressRows();
        SubsetGUI subset_gui = new SubsetGUI(metamorphosys);
        subset_gui.setVisible(true);
      }
    });
    choice_panel.add(jrun_mmsys, choice_csts);
    jinstall_umls.setPreferredSize(jrun_mmsys.getPreferredSize());
    jinstall_umls.setMinimumSize(jrun_mmsys.getPreferredSize());
    choice_csts.gridy++;

    //
    // Browse Subset Button
    //
    choice_csts.gridy++;
    JButton jbrowse_subset = new JButton("Browse my subset");
    jbrowse_subset.setBackground(new Color(rgb));
    jbrowse_subset.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        // Instantiate Application
        enableGlassPane();
        Thread t = new Thread(new Runnable() {
          public void run() {

            try {
              enableGlassPane();
              RRFBrowserGUI.main(new String[0]);
            } catch (Exception ex) {
              ex.printStackTrace();
              disableGlassPane();
              MMSToolkit
                  .reportError(WelcomeGUI.this,
                      "Unexpected exception.\nSee user console for details.",
                      false);
            }
          }
        });
        t.start();

      }
    });
    choice_panel.add(jbrowse_subset, choice_csts);
    jbrowse_subset.setPreferredSize(jrun_mmsys.getPreferredSize());
    jbrowse_subset.setMinimumSize(jrun_mmsys.getPreferredSize());
    choice_csts.gridy++;

    jinstall_umls.setPreferredSize(jrun_mmsys.getPreferredSize());

    //
    // Build MRCXT Button
    //
    choice_csts.gridy++;
    JButton jbuild_mrcxt = new JButton("Build MRCXT");
    jbuild_mrcxt.setBackground(new Color(rgb));
    jbuild_mrcxt.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        // Instantiate Application
        try {
          MMSToolkit.setUsingView(true);
          MMSToolkit.setReleaseDatLocation("../release.dat");
          
          enableGlassPane();
          MRCXTBuilderGUI mrcxt_builder_gui = new MRCXTBuilderGUI();
          mrcxt_builder_gui.setVisible(true);
          mrcxt_builder_gui.toFront();

        } catch (Exception ex) {
          ex.printStackTrace();
          disableGlassPane();
          MMSToolkit.reportError(WelcomeGUI.this,
              "Unexpected exception.\nSee user console for details.", false);
        }
      }
    });
    choice_panel.add(jbuild_mrcxt, choice_csts);
    jbuild_mrcxt.setPreferredSize(jrun_mmsys.getPreferredSize());
    jbuild_mrcxt.setMinimumSize(jrun_mmsys.getPreferredSize());
    choice_csts.gridy++;

    //
    // MetamorphoSys Text
    //
    text = new JTextPane();
    text.setOpaque(false);
    text.setEditable(false);
    text.setContentType("text/html");
    text
        .setText("<html><body><font style=\"font-size:18pt; font-family:serif; white-space: nowrap\" color=\""
            + yellow_str
            + "\"><b>Unified&nbsp;Medical&nbsp;Language&nbsp;System\u00AE</b></font></body></html>");
    choice_csts.insets = new Insets(60, 2, 0, 2);
    choice_panel.add(text, choice_csts);
    choice_csts.gridy++;

    choice_csts.insets = new Insets(2, 2, 0, 5);
    //
    // Icon Panel
    //
    JPanel icon_panel = new JPanel(new FlowLayout());
    icon_panel.setBackground(new Color(rgb));

    //
    // DHHS logo
    //
    ImageIcon hhs_icon = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/DHHSbird_logo.gif");
      BufferedImage image = SwingToolkit.readScaledImage(gif_url, 30, false);
      hhs_icon = new ImageIcon(image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/DHHSbird_logo.gif could not be loaded.");
    }
    JLabel hhs_label = new JLabel(hhs_icon);
    hhs_label.setMaximumSize(new Dimension(30, 30));
    hhs_label.setPreferredSize(new Dimension(30, 30));
    icon_panel.add(hhs_label);

    //
    // NIH logo
    //
    ImageIcon nih_icon = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/nihlogo.gif");
      BufferedImage image = SwingToolkit.readScaledImage(gif_url, 30, false);
      nih_icon = new ImageIcon(image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/nihlogo.gif could not be loaded.");
    }
    JLabel nih_label = new JLabel(nih_icon);
    nih_label.setMaximumSize(new Dimension(30, 30));
    nih_label.setPreferredSize(new Dimension(30, 30));
    icon_panel.add(nih_label);

    choiceicon_panel.add(choice_panel, BorderLayout.CENTER);
    choiceicon_panel.add(icon_panel, BorderLayout.SOUTH);

    base_panel.add(choiceicon_panel, BorderLayout.CENTER);

    //
    // Set content pane
    //
    getContentPane().add(base_panel, BorderLayout.CENTER);

    //
    // Prep panel for display
    //
    FontSizeManager.adjustFontSize(this);
    this.pack();
    setLocationRelativeTo(null);

    //
    // Configure window listener
    //
    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {
        System.exit(1);
      }
    });

  };

  /**
   * Builds the help menu items.
   * 
   * @param help_menu
   *          the help {@link JMenu}
   */
  private void buildHelpMenu(JMenu help_menu) {

    //
    // View README Menu Item
    //
    JMenuItem view_readme_menu_item = new JMenuItem("View README");
    view_readme_menu_item.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        SwingToolkit.displayTextFile(WelcomeGUI.this, "MetamorphoSys README",
            new File("../README.txt"), 20, 75);
      }
    });
    help_menu.add(view_readme_menu_item);

    //
    // View source copyrights
    //
    JMenuItem view_copyrights_menu_item = new JMenuItem(
        "View Source Copyrights");
    view_copyrights_menu_item.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        SwingToolkit.displayTextFile(WelcomeGUI.this, "Copyright Notice",
            new File("../Copyright_Notice.txt"), 20, 75);
      }
    });
    help_menu.add(view_copyrights_menu_item);

    //
    // Welcome to MetamorphoSys Help Menu Item
    //
    help_menu.add(MMSToolkit.getResourceHelpMenu("Welcome to MetamorphoSys",
        "config/WelcomeMetamorphoSysHelp.html", this));

    //
    // UMLS Homepage menu item
    //
    help_menu.add(MMSToolkit.getURLHelpMenu("UMLS Homepage",
        "http://www.nlm.nih.gov/research/umls/", this));

    //
    // Docs Home Page Menu Item
    //
    help_menu.add(MMSToolkit.getURLHelpMenu("UMLS Documentation",
        "http://www.nlm.nih.gov/research/umls/umlsdoc.html", this));

    //
    // NLM Home Page Menu Item
    //
    help_menu.add(MMSToolkit.getURLHelpMenu("NLM Homepage",
        "http://www.nlm.nih.gov", this));

    //
    // About Menu Item
    //
    JMenuItem about_menu_item = new JMenuItem(new AboutAction(
        "About MetamorphoSys", this));
    help_menu.add(about_menu_item);

  }

  //
  // GlassPaneListener Implementation
  //

  /**
   * Enable glass pane.
   */
  public void enableGlassPane() {
    gc.setVisible(true);
  }

  /**
   * Disable glass pane.
   */
  public void disableGlassPane() {
    gc.setVisible(false);
  }

  /**
   * Standard Application entry point. Running this main method will present the
   * user with a GUI frame with choices to either Install UMLS or to Run
   * MetamorphoSys.
   * 
   * @param args
   *          application arguments
   */
  public static void main(String[] args) {
    // Instantiate Application
    try {
      MMSToolkit.setUsingView(true);
      MMSToolkit.setReleaseDatLocation("../release.dat");
      WelcomeGUI welcome_gui = WelcomeGUI.getWelcomeGUI();
      welcome_gui.setVisible(true);
      welcome_gui.toFront();

      /*
       * Connection connection; String url = "jdbc:hsqldb:test_database"; try {
       * Class.forName("org.hsqldb.jdbcDriver"); connection =
       * DriverManager.getConnection( url, "SA", ""); System.out.println("opened
       * HSQLDB database"); } catch (Exception ex) { ex.printStackTrace(); }
       * FileOutputStream fos = new FileOutputStream(new File("config",
       * "test"));
       * 
       * PrintWriter pw = new PrintWriter(new BufferedWriter(new
       * UTF8OutputStreamWriter( fos, true), 1024 * 256));
       * 
       * pw.println("UTF8 BOM testing"); pw.close();
       * 
       * PushBackReader reader = new PushBackReader(new BufferedReader(new
       * UTF8InputStreamReader( new FileInputStream(new File("config",
       * "test"))), 256 * 1024)); System.out.println(reader.readLine());
       * reader.close();
       */

    } catch (Exception e) {
      e.printStackTrace();
      MMSToolkit.reportError(welcome_gui,
          "Unexpected exception.\nSee user console for details.", false);
    }
  }

} // End of WelcomeGUI class

