/*****************************************************************************
 *
 * Object:  BackwardAction.java
 * Author:  Deborah Shapiro
 *
 *****************************************************************************/
package gov.nih.nlm.mms.browser;

import gov.nih.nlm.swing.SwingToolkit;

import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.image.BufferedImage;
import java.net.URL;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.KeyStroke;

/**
 * Action used for backward navigation.
 * 
 * @author Deborah Shapiro (dshapiro@apelon.com)
 */
public class BackwardAction extends AbstractAction {

  private ConceptListManager clm;

  /**
   * Instantiates a {@link BackwardAction} with the specified
   * {@link ConceptListManager}.
   * @param clm the {@link ConceptListManager}
   */
  public BackwardAction(ConceptListManager clm) {
    super();

    this.clm = clm;

    putValue(Action.NAME, "Backward");
    putValue(Action.MNEMONIC_KEY, new Integer((int) 'b'));
    putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('B',
        Event.CTRL_MASK));
    putValue(Action.SHORT_DESCRIPTION, "Navigate backward");
    ImageIcon clm_icon = null;
    BufferedImage clm_image = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/arrows_blue_004.gif");
      clm_image = SwingToolkit.readScaledImage(gif_url, 17, false);
      clm_icon = new ImageIcon(clm_image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/arrows_blue_004.gif could not be loaded.");
    }
    putValue(Action.SMALL_ICON, clm_icon);
    //setEnabled(false);
  }

  /**
   * Action performed.
   * 
   * @param e
   *          {@link ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    RRFBrowserGUI.getRRFBrowserGUI().enableGlassPane();
    Thread thread = new Thread(new Runnable() {
      public void run() {
        clm.backward();
        RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
      }
    });
    thread.start();
  }

}
