/*****************************************************************************
 * Package: gov.nih.nlm.mms.browser
 * Object:  OpenSubsetAction.java
 *
 *
 ****************************************************************************/
package gov.nih.nlm.mms.browser;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.mms.MetamorphoSysInputStream;
import gov.nih.nlm.mms.UserConfiguration;
import gov.nih.nlm.swing.SwingToolkit;

import java.awt.event.ActionEvent;
import java.awt.image.BufferedImage;
import java.io.File;
import java.net.URL;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JFileChooser;
import javax.swing.SwingUtilities;

/**
 * This class is used for the <code>File->Open Subset</code> menu of the
 * {@link RRFBrowserGUI}.
 * 
 * @author Deborah Shapiro
 */
public class OpenSubsetAction extends AbstractAction {

  //
  // Configuration object
  //
  private UserConfiguration user_configuration;

  private File source_dir;

  //
  // Constructor
  //

  /**
   * Instantiates an {@link OpenSubsetAction}.
   * 
   * @param uc
   *          {@link UserConfiguration}
   * @param clm
   *          {@link ConceptListManager}
   */
  public OpenSubsetAction(UserConfiguration uc, ConceptListManager clm) {

    super();
    user_configuration = uc;

    // configure action
    putValue(Action.NAME, "Open Subset");
    putValue(Action.SHORT_DESCRIPTION, "Open Subset");

    ImageIcon clm_icon = null;
    BufferedImage clm_image = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/Open24.gif");
      clm_image = SwingToolkit.readScaledImage(gif_url, 17, false);
      clm_icon = new ImageIcon(clm_image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/Open24.gif could not be loaded.");
    }
    putValue(Action.SMALL_ICON, clm_icon);
  }

  /**
   * Opens a file chooser dialog.
   * 
   * @param e
   *          an {@link java.awt.event.ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    RRFBrowserGUI.getRRFBrowserGUI().enableGlassPane();
    Thread thread = new Thread(new Runnable() {
      public void run() {
        try {
          //
          // Get the selected file as a starting point
          //
          final File default_dir = RRFBrowserGUI.getRRFBrowserGUI()
              .getSubsetDirectory();

          //
          // Prompt the user to choose a file
          //
          try {
            SwingUtilities.invokeAndWait(new Runnable() {
              public void run() {

                source_dir = MMSToolkit.chooseFile(
                    "Select and Open the Subset Folder", "Open..",
                    JFileChooser.DIRECTORIES_ONLY, default_dir, default_dir,
                    RRFBrowserGUI.getRRFBrowserGUI());
              }
            });

          } catch (Exception e) {
            e.printStackTrace();
            MMSToolkit.reportError(RRFBrowserGUI.getRRFBrowserGUI(),
                "Unexpected error while opening subset folder.\n"
                    + "See the console for more details.", false);
            RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
          }

          //
          // If a directory was selected, set the source path
          //
          if (source_dir != null) {
            MetamorphoSysInputStream is = user_configuration.getInputStream();
            if (is.validateSourcePath(source_dir.getAbsolutePath())) {

              //
              // Here is where we really handle a new subset directory
              //
              RRFBrowserGUI.getRRFBrowserGUI()
                  .subsetDirectoryOpened(source_dir);

            } else
              MMSToolkit.reportError(RRFBrowserGUI.getRRFBrowserGUI(), is
                  .getValidationErrors()[0], false);
          }
        } catch (Exception ex) {
          ex.printStackTrace();
          MMSToolkit.notifyUser(RRFBrowserGUI.getRRFBrowserGUI(),
              "Unexpected error opening a subset.\n"
                  + "See the console for more details.");
          RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
        }
        RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
      }
    });
    thread.start();
  }
}
