/*****************************************************************************
 *
 * Object:  PrintAction.java
 * Author:  Brian Carlsen
 *
 *
 *****************************************************************************/
package gov.nih.nlm.mms.browser;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.swing.SwingToolkit;

import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.image.BufferedImage;
import java.net.URL;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.KeyStroke;

/**
 * Action used for printing a concept view.
 * 
 * @author Brian Carlsen (bcarlsen@apelon.com)
 */
public class PrintAction extends AbstractAction {

  /**
   * Instantiates a {@link PrintAction}.
   */
  public PrintAction() {
    super();

    putValue(Action.NAME, "Print");
    putValue(Action.MNEMONIC_KEY, new Integer((int) 'p'));
    putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('P',
        Event.CTRL_MASK));
    putValue(Action.SHORT_DESCRIPTION, "Print");
    ImageIcon clm_icon = null;
    BufferedImage clm_image = null;
    try {
      URL gif_url = this.getClass().getClassLoader().getResource(
          "config/Print24.gif");
      clm_image = SwingToolkit.readScaledImage(gif_url, 17, false);
      clm_icon = new ImageIcon(clm_image);
    } catch (Exception ex) {
      throw new RuntimeException(
          "Scaled version of config/Print24.gif could not be loaded.");
    }
    putValue(Action.SMALL_ICON, clm_icon);
    //setEnabled(false);
  }

  /**
   * Action performed.
   * 
   * @param e
   *          {@link ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    RRFBrowserGUI.getRRFBrowserGUI().enableGlassPane();
    Thread thread = new Thread(new Runnable() {
      public void run() {
        try {
          System.out.println("Printing Concept View...");
          ConceptView cv = RRFBrowserGUI.getRRFBrowserGUI().getReportsManager()
              .getCurrentView();
          cv.print();
        } catch (Exception ex) {
          ex.printStackTrace();
          MMSToolkit.notifyUser(RRFBrowserGUI.getRRFBrowserGUI(),
              "There was an error printing the concept view.\n"
                  + "See the console for more details.");
          RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
        }
        RRFBrowserGUI.getRRFBrowserGUI().disableGlassPane();
      }
    });
    thread.start();
  }

}
