/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms.filters;
 * Interface:  WordSearchFinderOptionsGUI.java
 *
 *************************************************************************/
package gov.nih.nlm.mms.browser;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.umls.meta.Atom;
import gov.nih.nlm.umls.meta.Concept;
import gov.nih.nlm.umls.meta.Language;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
//import java.io.File;
//import java.io.FileInputStream;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Hashtable;
//import java.util.Properties;

import javax.swing.Box;
//import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
//import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JPanel;
//import javax.swing.JRadioButton;
import javax.swing.JSlider;
//import javax.swing.JTextField;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;

/**
 * Options GUI for {@link WordSearchFinder}.
 * 
 * @author Deborah Shapiro
 */
public class WordSearchFinderOptionsGUI extends JDialog {

  //
  // Private Fields
  //
  private static final int MIN_THRESH = 1;

  private static final int MAX_THRESH = 100;

  private JSlider jthreshold;

  private JComboBox languages_box;

//  private JRadioButton regular_search = null;
//
//  private JRadioButton norm_search = null;
//
//  private final JButton browse_button = new JButton("Browse..");
//
//  private final JLabel lvg_config_label = new JLabel("LVG Configuration File:");
//
//  private final JTextField config_file_field = new JTextField(40);

  //
  // finder
  //
  private WordSearchFinder finder;

  //
  // Constructor
  //
  /**
   * Instantiates a {@link WordSearchFinderOptionsGUI}.
   * 
   * @param f
   *          the {@link WordSearchFinder}
   */
  public WordSearchFinderOptionsGUI(WordSearchFinder f) {
    super(RRFBrowserGUI.getRRFBrowserGUI());
    finder = f;
    setModal(true);
    setTitle("Word Search Options");
    initialize();
  };

  //
  // Methods
  //

  /**
   * Initialize the GUI.
   */
  private void initialize() {

    //
    // Set layout)
    //
    getContentPane().setLayout(new BorderLayout());

    //
    // Configure top-level panel
    //
    GridBagLayout gridbag = new GridBagLayout();
    JPanel data_panel = new JPanel(gridbag);
    GridBagConstraints constraints = new GridBagConstraints();
    constraints.fill = GridBagConstraints.HORIZONTAL;
    constraints.insets = new Insets(2, 2, 2, 2);

    //
    // add Header
    //
    constraints.gridy++;
    constraints.gridx = 2;
    constraints.gridwidth = 1;

    final FlowLayout done_layout = new FlowLayout();
    final JPanel done_panel = new JPanel(done_layout);
    final JPanel complete_panel = new JPanel(new BorderLayout());

    //
    // Compose menu bar
    //

    JMenuBar menu_bar = new JMenuBar();
    setJMenuBar(menu_bar);
    menu_bar.add(Box.createHorizontalGlue());
    JMenu help_menu = new JMenu("Help");
    menu_bar.add(help_menu);
    help_menu.add(MMSToolkit.getURLHelpMenu("LVG Norm Search Documentation  "
        + "", "http://umlslex.nlm.nih.gov/lvg/current/docs/userDoc/index.html",
        RRFBrowserGUI.getRRFBrowserGUI()));

    //
    // configure data_panel
    //
    final JLabel slider_label = new JLabel("Select Matching Threshold:");
    data_panel.add(slider_label, constraints);
    int init_thresh = new Double(finder.getThreshold() * 10000).intValue();
    jthreshold = new JSlider(JSlider.HORIZONTAL, MIN_THRESH, MAX_THRESH,
        init_thresh);
    jthreshold.setMajorTickSpacing(10);
    Hashtable labelTable = new Hashtable();
    labelTable.put(new Integer(1), new JLabel("More"));
    labelTable.put(new Integer(MAX_THRESH), new JLabel("Fewer"));
    jthreshold.setLabelTable(labelTable);
    jthreshold.setPaintLabels(true);
    constraints.gridy++;
    constraints.insets = new Insets(2, 2, 10, 2);
    data_panel.add(jthreshold, constraints);
    constraints.insets = new Insets(2, 2, 2, 2);

    final JLabel languages_label = new JLabel("Select a Language:");
    constraints.gridy++;
    data_panel.add(languages_label, constraints);
    final Language[] lats = Language.getLanguages();
    final String[] lat_values = new String[lats.length];
    for (int i = 0; i < lats.length; i++)
      lat_values[i] = getLanguageValue(lats[i]);
    Arrays.sort(lat_values);
    languages_box = new JComboBox(lat_values);
    languages_box.setSelectedItem(getLanguageValue(finder.getLanguage()));
    constraints.gridy++;
    constraints.insets = new Insets(2, 2, 10, 2);
    data_panel.add(languages_box, constraints);
    constraints.insets = new Insets(2, 2, 2, 2);

    //
    // Word Search Type Selection
    //
//    final JLabel search_label = new JLabel("Word Search Type:");
//    constraints.gridy++;
//    data_panel.add(search_label, constraints);
//    regular_search = new JRadioButton(WordSearchFinder.regular_mode);
//    norm_search = new JRadioButton(WordSearchFinder.normalized_mode
//        + " (English only)");
//    ButtonGroup group = new ButtonGroup();
//    group.add(regular_search);
//    group.add(norm_search);
//
//    regular_search.setSelected(finder.getSearchMode().startsWith(
//        WordSearchFinder.regular_mode));
//    regular_search.addActionListener(new ActionListener() {
//      public void actionPerformed(ActionEvent e) {
//        setLvgConfigEnabled(false);
//      }
//    });
//
//    constraints.gridy++;
//    data_panel.add(regular_search, constraints);
//
//    norm_search.setSelected(finder.getSearchMode().startsWith(
//        WordSearchFinder.normalized_mode));
//    norm_search.addActionListener(new ActionListener() {
//      public void actionPerformed(ActionEvent e) {
//        setLvgConfigEnabled(true);
//      }
//    });
//
//    constraints.gridy++;
//    data_panel.add(norm_search, constraints);

    //
    // Add lvg config file: label, field, browse button
    //
//    constraints.gridy++;
//
//    constraints.insets = new Insets(10, 2, 2, 2);
//    data_panel.add(lvg_config_label, constraints);
//    constraints.insets = new Insets(2, 2, 2, 2);
//    constraints.gridy++;
//
//    JPanel config_file_button_panel = new JPanel(new FlowLayout());
//    config_file_field.setEditable(false);
//    config_file_button_panel.add(config_file_field);
//    config_file_field.setText(finder.getLvgConfigFile());
//    config_file_button_panel.add(browse_button);
//    data_panel.add(config_file_button_panel, constraints);
//
//    browse_button.addActionListener(new ActionListener() {
//      public void actionPerformed(ActionEvent e) {
//        try {
//          //
//          // Select a lvg configuration file
//          //
//          File selected_file = null;
//          if (!config_file_field.getText().equals("")) {
//            selected_file = new File(config_file_field.getText())
//                .getCanonicalFile();
//          }
//          File source_dir = MMSToolkit.chooseFile(
//              "Select and Open the LVG configuration file", "Open..",
//              JFileChooser.FILES_ONLY, selected_file, selected_file, MMSToolkit
//                  .getGui());
//
//          if (source_dir != null) {
//            config_file_field.setText(source_dir.getAbsolutePath());
//            finder.setLvgConfigFile(source_dir.getAbsolutePath());
//          }
//        } catch (Exception ex) {
//          ex.printStackTrace();
//          MMSToolkit.reportError(WordSearchFinderOptionsGUI.this,
//              "Unexpected error while setting lvg configuration file.\n"
//                  + "See console for details.", false);
//        }
//      }
//    });
//    if (regular_search.isSelected()) {
//      setLvgConfigEnabled(false);
//    }

    //
    // configure done_panel
    //
    final JButton jdone = new JButton("Done");
    jdone.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
//        if (norm_search.isSelected())
//          if (!validateNormSearch())
//            return;
        finder.setThreshold(new Integer((int) jthreshold.getValue())
            .doubleValue() / 10000);
        finder.setLanguage(getSelectedLanguage());
//        finder.setSearchMode(getSearchMode());
//        finder.setLvgConfigFile(config_file_field.getText());
        WordSearchFinderOptionsGUI.this.dispose();
      }
    });
    done_panel.add(jdone);
    final JButton jcancel = new JButton("Cancel");
    jcancel.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {
        dispose();
      }
    });
    done_panel.add(jcancel);

    //
    // Add the sub-panels to complete_panel
    //
    complete_panel.add(data_panel, BorderLayout.CENTER);
    complete_panel.add(done_panel, BorderLayout.SOUTH);
    final EtchedBorder etched_border = new EtchedBorder(EtchedBorder.RAISED);
    complete_panel.setBorder(new CompoundBorder(etched_border, new EmptyBorder(
        10, 10, 10, 10)));

    //
    // Pack and prep frame
    //
    getContentPane().add(complete_panel, BorderLayout.CENTER);
    getRootPane().setDefaultButton(jdone);
    this.pack();
    this.setLocationRelativeTo(null);
  }

//  /**
//   * Enables and disables the components related to selection of an Lvg
//   * configuration file.
//   *
//   * @param enabled
//   *          <code>boolean</code> true if components should be enabled false
//   *          otherwise
//   */
//  private void setLvgConfigEnabled(boolean enabled) {
//    browse_button.setEnabled(enabled);
//    lvg_config_label.setEnabled(enabled);
//    config_file_field.setEnabled(enabled);
//  }

  /**
   * Returns the box value for the language.
   * 
   * @param lat
   *          {@link Language}
   * @return i.e. English (ENG)
   */
  private String getLanguageValue(Language lat) {
    return lat.getDescription() + " (" + lat.getAbbreviation() + ")";
  }

  /**
   * Returns the language indicated by the combo box.
   * 
   * @return {@link Language} selected by the combo box
   */
  private Language getSelectedLanguage() {
    String value = (String) languages_box.getSelectedItem();
    return Language.getLanguage(value.substring(value.indexOf('(') + 1, value
        .indexOf(')')));
  }

//  /**
//   * Returns the search mode indicated by the radio button selections.
//   *
//   * @return {@link String} indicating search mode
//   */
//  private String getSearchMode() {
//    if (regular_search.isSelected())
//      return WordSearchFinder.regular_mode;
//    else if (norm_search.isSelected())
//      return WordSearchFinder.normalized_mode;
//    else
//      return "";
//  }

//  /**
//   * Validates the lvg configuration file settins required when Norm Word Search
//   * is selected
//   *
//   * @return <code>boolean</code> true if validation passes false otherwise
//   */
//  private boolean validateNormSearch() {
//    // confirm user entered a config file
//    if (config_file_field.getText().equals("")) {
//      MMSToolkit.reportError(WordSearchFinderOptionsGUI.this,
//          "The Normalized Word Search mode requires the\n"
//              + "path to a properly configured LVG Configuration File.\n"
//              + "The default LVG Configuration File is named lvg.properties.\n"
//              + "Please enter a LVG Configuration File.", false);
//      return false;
//    }
//
//    // confirm language is English
//    if (getSelectedLanguage() != Language.getLanguage("ENG")) {
//      MMSToolkit.reportError(WordSearchFinderOptionsGUI.this,
//          "The Normalized Word Search mode requires the \n"
//              + "language selection to be English.\n"
//              + "Non-English words cannot be normalized.\n"
//              + "Please select English from the Language menu.", false);
//      return false;
//    }
//
//    // confirm file is of the Properties format
//    Properties props = new Properties();
//    try {
//      FileInputStream propInputStream = new FileInputStream(config_file_field
//          .getText());
//      props.load(propInputStream);
//    } catch (Exception e) {
//      MMSToolkit.reportError(WordSearchFinderOptionsGUI.this,
//          "Error while loading LVG Configuration File.\n"
//              + "File is not of the required properties format.\n"
//              + "The default LVG Configuration File is named lvg.properties.",
//          false);
//      return false;
//    }
//
//    // confirm configuration file has an LVG_DIR property
//    if (!props.containsKey("LVG_DIR")) {
//      MMSToolkit.reportError(WordSearchFinderOptionsGUI.this,
//          "Error while loading LVG Configuration File.\n"
//              + "File does not contain required LVG_DIR property.\n"
//              + "The default LVG Configuration File is named lvg.properties.\n"
//              + "It is generally found in the LVG_DIR/data/config\n"
//              + "directory.", false);
//      return false;
//    }
//
//    // confirm LVG_DIR is valid
//    String lvg_dir = props.getProperty("LVG_DIR");
//    File lvg_dir_file = new File(lvg_dir);
//    if (!lvg_dir_file.exists()) {
//      MMSToolkit.reportError(WordSearchFinderOptionsGUI.this, "Unable to find "
//          + lvg_dir_file + ".\n"
//          + "The LVG_DIR property in the LVG Configuration File\n"
//          + "must point to a valid LVG home directory.\n"
//          + "Please reconfigure the LVG Configuration File.", false);
//      return false;
//    }
//    if ((!lvg_dir.endsWith("\\")) && (!lvg_dir.endsWith("/"))) {
//      MMSToolkit
//          .reportError(
//              WordSearchFinderOptionsGUI.this,
//              "The LVG_DIR property in the LVG Configuration File\n"
//                  + "must point to a valid LVG home directory which ends with\n"
//                  + "a file separator.\n"
//                  + "Please add a file separator to the end of the LVG_DIR property.",
//              false);
//      return false;
//    }
//
//    return true;
//  }

  /**
   * {@link Concept} {@link Comparator} based on CUI.
   */
  protected class CuiSortOrderComparator implements Comparator {

    /**
     * Instantiates a CuiSortOrderComparator.
     */
    public CuiSortOrderComparator() {
    };

    /**
     * Compares the specified field of each {@link String} object.
     * 
     * @param o1
     *          the first {@link Object} to be compared.
     * @param o2
     *          the second {@link Object} to be compared.
     * @return An <code>int</code> which might be negative integer, zero, or a
     *         positive integer as the first argument is less than, equal to, or
     *         greater than the second.
     */
    public int compare(Object o1, Object o2) {
      if (o1 == null || o2 == null || !(o1 instanceof Concept)
          || !(o2 instanceof Concept))
        return 0;
      Concept s1 = (Concept) o1;
      Concept s2 = (Concept) o2;

      String cui1 = s1.getCui();
      String cui2 = s2.getCui();

      return cui1.compareTo(cui2);
    }

    /**
     * Returns the display name for the {@link Comparator}.
     * 
     * @return {@link String}
     */
    public String toString() {
      return "CUI Sort Order";
    }

    public boolean equals(Comparator comp) {
      return comp instanceof CuiSortOrderComparator;
    }

  } // end of CuiSortOrderComparator

  /**
   * {@link Concept} {@link Comparator} based on preferred name.
   */
  protected class StringSortOrderComparator implements Comparator {

    /**
     * Instantiates a comparator.
     */
    public StringSortOrderComparator() {
    }

    /**
     * Compares the specified field of each {@link String} object.
     * 
     * @param o1
     *          the first {@link Object} to be compared.
     * @param o2
     *          the second {@link Object} to be compared.
     * @return An <code>int</code> which might be negative integer, zero, or a
     *         positive integer as the first argument is less than, equal to, or
     *         greater than the second.
     */
    public int compare(Object o1, Object o2) {
      if (o1 == null || o2 == null || !(o1 instanceof Concept)
          || !(o2 instanceof Concept))
        return 0;
      final Concept c1 = (Concept) o1;
      final Concept c2 = (Concept) o2;

      return getPreferredName(c1).compareTo(getPreferredName(c2));
    }

    /**
     * Looks up concept preferred name.
     * 
     * @param c
     *          the {@link Concept}
     * @return the preferred name of the {@link Concept}
     */
    public String getPreferredName(final Concept c) {
      final Atom[] atoms = c.getAtoms();
      for (int i = 0; i < atoms.length; i++) {
        final Atom atom = atoms[i];
        if (atom.hasPreferredAtomIdentifier()
            && atom.hasPreferredStringIdentifier()
            && atom.hasPreferredTermIdentifier()
            && atom.getLanguage().equals(getSelectedLanguage())) {
          return atom.getStr().toLowerCase();
        }
      }
      return "";
    }

    public String toString() {
      return "Concept Name Sort Order";
    }

    public boolean equals(Comparator comp) {
      return comp instanceof StringSortOrderComparator;
    }

  } // end of StringSortOrderComparator

} // End of WordSearchFinderOptionsGUI class
