/****************************************************************************
 *
 * Package: gov.nih.nlm.mms.browser
 * Object:  ExitRRFAction.java
 *
 *****************************************************************************/
package gov.nih.nlm.mms.cxt;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.mms.WelcomeGUI;
import gov.nih.nlm.mms.browser.RRFBrowserGUI;

import java.awt.Event;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.KeyStroke;

/**
 * Represents an action for exiting the application. Used for the
 * <code>File -> Exit</code> menu of {@link MRCXTBuilderGUI}.
 * 
 * @author Deborah Shapiro
 */
public class ExitMRCXTAction extends AbstractAction {

	private MRCXTBuilderGUI gui = null;
	
  /**
   * Instantiates an {@link ExitMRCXTAction}
   * @param gui {@link MRCXTBuilderGUI}
   */
  public ExitMRCXTAction(MRCXTBuilderGUI gui) {
  	this.gui = gui;
    putValue(Action.NAME, "Exit");
    putValue(Action.SHORT_DESCRIPTION, "Exit");
    putValue(Action.MNEMONIC_KEY, new Integer((int) 'q'));
    putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Q',
        Event.CTRL_MASK));
  }

  /**
   * Exits the application.
   * 
   * @param e
   *          the {@link ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    try {
      MMSToolkit.exitToWelcomeGUI(gui);
    } catch (Exception ex) {
      // do nothing if unable to save settings
    }
    MMSToolkit.Exit(0);
  }

}
