/*****************************************************************************
 * Package: gov.nih.nlm.mms.cxt
 * Object:  OpenSubsetAction.java
 *
 ****************************************************************************/
package gov.nih.nlm.mms.cxt;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.mms.MetamorphoSysInputStream;
import gov.nih.nlm.mms.UserConfiguration;

import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JFileChooser;
import javax.swing.SwingUtilities;

/**
 * This class is used for the Browse button on the MRCXTBuilderGUI.
 * 
 * @author Deborah Shapiro
 */
public class OpenSubsetAction extends AbstractAction {

  //
  // Configuration object
  //
  private UserConfiguration user_configuration;

  //
  // GUI
  //
  private MRCXTBuilderGUI gui;

  //
  // Default dir selection
  //
  File default_dir = null;

  //
  // Constructor
  //

  /**
   * Instantiates an {@link OpenSubsetAction}.
   * 
   * @param uc
   *          {@link UserConfiguration}
   * @param gui
   *          {@link MRCXTBuilderGUI}
   */
  public OpenSubsetAction(UserConfiguration uc, MRCXTBuilderGUI gui) {
    super();
    user_configuration = uc;
    this.gui = gui;
    default_dir = new File(user_configuration.getSourcePaths()[0]);

    // configure action
    putValue(Action.NAME, "Browse...");
    putValue(Action.SHORT_DESCRIPTION, "Browse...");
  }

  /**
   * Opens a small dialog informing the user about the application.
   * 
   * @param e
   *          an {@link java.awt.event.ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    gui.enableGlassPane();
    //
    // Prompt the user to choose a file
    //
    final File source_dir = MMSToolkit.chooseFile(
        "Select and Open the Subset Folder", "Open..",
        JFileChooser.DIRECTORIES_ONLY, default_dir, default_dir, gui);
    
    Thread runner = new Thread() {
      public void run() {
        try {

          //
          // If a directory was selected, set the source path
          //
          if (source_dir != null) {
            default_dir = source_dir;
            final MetamorphoSysInputStream is = user_configuration.getInputStream();
            if (is.validateSourcePath(source_dir.getAbsolutePath())) {
              SwingUtilities.invokeAndWait(
                  new Runnable() {
                    public void run() {
                      gui.subsetDirectoryOpened(default_dir);
                      
                    }
                  }
              );
              
            } else
              MMSToolkit.reportError(gui, is.getValidationErrors()[0], false);
          }
        } catch (Exception ex) {
          ex.printStackTrace();
          MMSToolkit.notifyUser(gui, "Unexpected error opening a subset.\n"
              + "See the console for more details.");
          gui.disableGlassPane();
        }
        gui.disableGlassPane();
      }
    };
    runner.start();
  }
}