/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms.filters;
 * Interface:  SemanticTypesToRemoveOptionsGUI.java
 *
 *************************************************************************/
package gov.nih.nlm.mms.filters;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.swing.FontSizeManager;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;

/**
 * Semantic Types To Remove options dialog to set advanced options.
 * 
 * @author Deborah Shapiro
 */

public class SemanticTypesToRemoveOptionsGUI extends JDialog implements
    ActionListener {

  //
  // Private Fields
  //
  private JRadioButton any_sty = new JRadioButton(
      "Remove concept with ANY selected semantic type.", false);

  private JRadioButton all_stys = new JRadioButton(
      "Remove concept with ALL selected semantic types.", false);

  private ButtonGroup radio_group = new ButtonGroup();

  private JButton jdone = new JButton("Done");

  private SemanticTypesToRemoveFilter filter;

  /**
   * Creates a modal dialog box and calls method to initialize it.
   * 
   * @param f
   *          {@link SemanticTypesToRemoveFilter}
   */
  public SemanticTypesToRemoveOptionsGUI(SemanticTypesToRemoveFilter f) {
    super(MMSToolkit.getGui());
    filter = f;
    setModal(true);
    setTitle("Advanced Semantic Types To Exclude Options");
    initialize();
  };

  //
  // Methods
  //
  /**
   * This method sets up the GUI
   */
  private void initialize() {

    getContentPane().setLayout(new BorderLayout());
    JPanel data_panel = new JPanel(new GridBagLayout());
    JPanel done_panel = new JPanel(new GridBagLayout());
    JPanel complete_panel = new JPanel(new BorderLayout());
    GridBagConstraints constraints = new GridBagConstraints();
    constraints.fill = GridBagConstraints.BOTH;
    constraints.insets = new Insets(2, 2, 2, 2);

    if (filter.removeSelectedSemanticTypes()) {
      any_sty.setText("Remove concept with ANY selected semantic type.");
      all_stys.setText("Remove concept with ALL selected semantic types.");
    } else {
      any_sty.setText("Include concept with ANY selected semantic types.");
      all_stys.setText("Include concept with ALL selected semantic types.");
    }

    radio_group.add(any_sty);
    radio_group.add(all_stys);

    constraints.gridy = 0;
    constraints.gridwidth = 3;
    constraints.gridy++;
    data_panel.add(any_sty, constraints);
    constraints.gridy++;
    data_panel.add(all_stys, constraints);

    if (filter.anySty())
      any_sty.setSelected(true);
    else
      all_stys.setSelected(true);

    constraints.gridx = 0;
    constraints.gridwidth = 1;
    constraints.weightx = 1.0;
    constraints.gridy++;
    jdone.addActionListener(this);
    done_panel.add(jdone, constraints);

    // Add the panel
    complete_panel.add(data_panel, BorderLayout.NORTH);
    complete_panel.add(done_panel, BorderLayout.SOUTH);
    EtchedBorder etched_border = new EtchedBorder(EtchedBorder.RAISED);
    complete_panel.setBorder(new CompoundBorder(etched_border, new EmptyBorder(
        10, 10, 10, 10)));

    getRootPane().setDefaultButton(jdone);
    getContentPane().add(complete_panel, BorderLayout.CENTER);
    FontSizeManager.adjustFontSize(this);
    this.pack();
    this.setLocationRelativeTo(null);
  };

  /**
   * Responds to the user pushing the done button to register changes made on
   * the {@link SemanticTypesToRemoveOptionsGUI}.
   * 
   * @param e
   *          {@link java.awt.event.ActionEvent}
   */
  public void actionPerformed(ActionEvent e) {
    if (e.getActionCommand().equals("Done")) {
      if (any_sty.isSelected())
        filter.setAnySty(true);
      else
        filter.setAnySty(false);
      setVisible(false);
      this.dispose();
    }
  }

}// End of SemanticTypesToRemoveOptionsGUI class

