/**************************************************************************
 *
 * Package:    gov.nih.nlm.mms.filters;
 * Interface:  SuppressibleTermgroupsOptionsGUI.java
 *
 *************************************************************************/
package gov.nih.nlm.mms.filters;

import gov.nih.nlm.mms.MMSToolkit;
import gov.nih.nlm.swing.FontSizeManager;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;

/**
 * Suppressiblity Options GUI.
 * 
 * @author Deborah Shapiro
 */

public class SuppressibleTermgroupsOptionsGUI extends JDialog {

  //
  // GUI elements
  //
  private final JCheckBox remove_suppressible_data = new JCheckBox(
      "Remove Suppressible Data.", false);

  //
  // Filter
  //
  private SuppressibleTermgroupsFilter filter;

  //
  // Constructor
  //

  /**
   * Instantiates a {@link SuppressibleTermgroupsOptionsGUI} connected to the
   * specified {@link SuppressibleTermgroupsFilter}.
   * 
   * @param f
   *          the {@link SuppressibleTermgroupsFilter}
   */
  public SuppressibleTermgroupsOptionsGUI(SuppressibleTermgroupsFilter f) {
    super(MMSToolkit.getGui());
    filter = f;
    setModal(true);
    setTitle("Advanced Supppressibility Options");
    this.setLocationRelativeTo(null);

    //
    // Initialize GUI
    //
    final DataChangeListener dcl = new DataChangeListener();

    getContentPane().setLayout(new BorderLayout());
    final JPanel data_panel = new JPanel(new GridBagLayout());
    final JPanel done_panel = new JPanel(new GridBagLayout());
    final JPanel complete_panel = new JPanel(new BorderLayout());
    final GridBagConstraints constraints = new GridBagConstraints();
    constraints.fill = GridBagConstraints.BOTH;
    constraints.insets = new Insets(2, 2, 2, 2);

    constraints.gridy = 0;
    constraints.gridwidth = 3;
    constraints.gridy++;
    remove_suppressible_data.addActionListener(dcl);
    remove_suppressible_data.setSelected(filter.removeSuppressibleData());
    data_panel.add(remove_suppressible_data, constraints);
    constraints.gridy++;

    constraints.gridx = 0;
    constraints.gridwidth = 1;
    constraints.weightx = 1.0;
    constraints.gridy++;
    final JButton jdone = new JButton("Done");
    jdone.addActionListener(dcl);
    done_panel.add(jdone, constraints);

    // Add the panel
    complete_panel.add(data_panel, BorderLayout.NORTH);
    complete_panel.add(done_panel, BorderLayout.SOUTH);
    final EtchedBorder etched_border = new EtchedBorder(EtchedBorder.RAISED);
    complete_panel.setBorder(new CompoundBorder(etched_border, new EmptyBorder(
        10, 10, 10, 10)));

    getRootPane().setDefaultButton(jdone);
    getContentPane().add(complete_panel, BorderLayout.CENTER);
    FontSizeManager.adjustFontSize(this);
    this.pack();
  };

  /**
   * This requires the user to confirm choice to remove suppressible data. It
   * updates the GUI based on the user decision.
   */
  public void confirmResponse() {
    boolean user_choice = true;
    if (remove_suppressible_data.isSelected() == true) {
      user_choice = MMSToolkit.confirmRequest(MMSToolkit.getGui(),
          "Do you really want to remove suppressible data?");
    }
    if (!user_choice) {
      remove_suppressible_data.setSelected(false);
    }
    this.pack();
  }

  //
  // Inner classes
  //

  /**
   * Handles data changes.
   */
  private class DataChangeListener implements ActionListener {

    /**
     * Instantiates an empty {@link DataChangeListener}.
     */
    public DataChangeListener() {
    };

    /**
     * Handle GUI selections.
     * 
     * @param e
     *          the event
     */
    public void actionPerformed(ActionEvent e) {
      if (e.getActionCommand().equals("Done")) {
        filter.setRemoveSuppressibleData(remove_suppressible_data.isSelected());
        setVisible(false);
        SuppressibleTermgroupsOptionsGUI.this.dispose();
      } else if (e.getActionCommand().equals("Remove Suppressible Data.")) {
        confirmResponse();
      }
    }
  }

} // End of SuppressibleTermgroupsOptionsGUI class
