/**************************************************************************
 * Package:     gov.nih.nlm.umls.io
 * Interface:   MetathesaurusOutputStream.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.io;

import gov.nih.nlm.umls.meta.IndexEntry;
import gov.nih.nlm.umls.meta.ReleaseMetadata;

import java.io.IOException;
import java.util.List;

/**
 * Generically represents a way for writing the Metathesaurus to some
 * output source.  The input could be files, a database, or pretty much
 * anything else.
 *
 * @author Deborah Shapiro
 */
public interface MetathesaurusOutputStream extends ConceptOutputStream{

  /**
   * Writes an {@link IndexEntry} to the output stream.
   * @param index_entry the {@link IndexEntry} to write out
   * @throws IOException if there is a problem reading the index entry
   */
  public void writeIndexEntry(IndexEntry index_entry) throws IOException;

  /**
   * Write the {@link ReleaseMetadata} to the output stream.
   * @param release_metadata the {@link ReleaseMetadata} to write out
   * @throws IOException if there is a problem
   *         reading the release metadata
   */
  public void writeReleaseMetadata(ReleaseMetadata release_metadata)
    throws IOException;

  /**
   * Sets the list of suis that are candidates to be ambiguous.
   * @param suis the list of suis that are candidates to be ambiguous
   */
  public void setCandidateAmbiguousStringIdentifiers(String [] suis);

  /**
   * Sets the list of suis that are candidates to be ambiguous.
   * @param suis the list of suis that are candidates to be ambiguous
   */
  public void setCandidateAmbiguousStringIdentifiers(List suis);

  /**
   * Sets the list of terms that are candidates to be ambiguous.
   * @param luis the list of terms that are candidates to be ambiguous
   */
  public void setCandidateAmbiguousTermIdentifiers(String[] luis);

  /**
   * Sets the list of terms that are candidates to be ambiguous.
   * @param luis the list of terms that are candidates to be ambiguous
   */
  public void setCandidateAmbiguousTermIdentifiers(List luis);

}