/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   AbstractExpandedForm.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Abstract implementation of {@link ExpandedForm} providing
 * <code>equals</code>, <code>hashCode</code>, <code>toString</code>,
 * and <code>compareTo</code> methods to any descendents.
 * All classes implementing {@link ExpandedForm} should probably
 * extend this class instead.
 *
 * @author Brian Carlsen, Deborah Shapiro
 */
public abstract class AbstractExpandedForm  implements ExpandedForm {

  /**
   * Compares the given {@link Object} with this {@link ExpandedForm}
   * for equality.
   * @param o  parameter to be compared to this {@link ExpandedForm}
   * @return <code>true</code> if they are equal
   *         <code>false</code> otherwise
   */
  public boolean equals(Object o) {
    return this == o;
  }

  /**
   * Compares the given {@link Object} with this {@link ExpandedForm}.
   * @param o parameter to be compared to this {@link ExpandedForm}
   * @return -1 if this object is less than the given {@link Object} parameter
   *          0 if this object is equal to the given {@link Object} parameter
   *          1 if this object is greater than the given {@link Object} parameter
   */
  public int compareTo(Object o) {
    if (o==null || !(o instanceof ExpandedForm))
      return 0;
    return getAbbreviation().compareTo(((ExpandedForm)o).getAbbreviation());
  }

  /**
   * Return a hash code based on key fields.
   * @return a hash code based on key fields
   */
  public int hashCode() {
    return getAbbreviation().hashCode();
  }

  /**
   * Return a string representation for an {@link Object} consisting
   * of its subkey.
   * @return subkey
   */
  public String toString() {
    return getAbbreviation();
  }
}