/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   AttributeValue.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Represents information an attribute name and value associated
 * with an {@link AttributeContext}.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link AttributeValue}
 * <p><center><img src="AttributeValue.gif"></center>
 * <p>
 * @see AttributeContext
 *
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface AttributeValue extends AttributeElement, Comparable,
  ContentViewElement, SuppressibleElement {

  /**
   * Returns the {@link AttributeName} (ATN).
   * @return the {@link AttributeName}
   */
  public AttributeName getAttributeName();

  /**
   * Returns the {@link AttributeName} (ATN).
   * This is shorthand for {@link #getAttributeName()}.
   * @return the {@link AttributeName}
   */
  public AttributeName getAtn();

  /**
   * Sets the {@link AttributeName} (ATN).
   * @param atn the {@link AttributeName}
   */
  public void setAttributeName(AttributeName atn);

  /**
   * Sets the {@link AttributeName} (ATN).
   * This is shorthand for {@link #setAttributeName(AttributeName)}.
   * @param atn the {@link AttributeName}
   */
  public void setAtn(AttributeName atn);

  /**
   * Returns the attribute value (ATV).
   * @return the attribute value
   */
  public String getAttributeValue();

  /**
   * Returns the attribute value (ATV).
   * This is shorthand for {@link #getAttributeValue()}.
   * @return the attribute value
   */
  public String getAtv();

  /**
   * Sets the attribute value (ATV).
   * @param atv the attribute value
   */
  public void setAttributeValue(String atv);

  /**
   * Sets the attribute value (ATV).
   * This is shorthand for {@link #setAttributeValue(String)}.
   * @param atv the attribute value
   */
  public void setAtv(String atv);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link AttributeValue} fields
   */
  public String getKeyFields();
}