/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Class:       ContentView.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Defines the content view for a {@link ConceptElement}. The various
 * methods indicate whether or not this object belongs to the specified
 * content view.
 *
 * @author Brian Carlsen, Deborah Shapiro
 */
public class ContentView {

  //
  // the CVF field value
  //
  private long value;

  /**
   * Instantiates an empty {@link ContentView}.
   */
  public ContentView() {};

  /**
   * Instantiates a {@link ContentView} from the specified {@link String} value.
   * @param value {@link String}
   */
  public ContentView(String value) {
    this();
    setValue(value);
  };

  /**
   * Instantiates a {@link ContentView} from the specified <code>long</code> value.
   * @param value <code>long</code>
   */
  public ContentView(long value) {
    this();
    setValue(value);
  };

  /**
   * Returns the value of the content view flag.
   * @return the long value
   */
  public long getValue() {
    return value;
  }

  /**
   * Sets the value of the content view flag. Each "bit" of the
   * value indicates membership in a particular view.
   * @param val the value of the content view flag
   */
  public void setValue(String val) {
    value = val.equals("") ? 0 : Long.parseLong(val);
  }

  /**
   * Sets the value of the content view flag. Each "bit" of the
   * value indicates membership in a particular view.
   * @param val the value of the content view flag as a long
   */
  public void setValue(long val) {
    value = val;
  }

  /**
   * Indicates whether or not to keep the parent element by determining
   * if this {@link ContentView} matches the one passed in.
   * @param cv represents the set of views to keep
   * @return <code>true</code> to keep, <code>false</code> otherwise
   */
  public boolean keep(ContentView cv) {
    return ((value & cv.getValue()) != 0);
  }

  /**
   * Returns {@link String} representation.
   * @return {@link String} representation
   */
  public String toString() { return String.valueOf(value); }
}