/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   Context.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

import java.util.List;

/**
 * Represents a grouping of {@link StringContext}s all of which
 * share the same string identifier.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link ContextGroup}
 * <p><center><img src="ContextGroup.gif"></center>
 * <p>
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface ContextGroup extends Comparable, ConceptElement {

  /**
   * Return the {@link StringInfo}.
   * @return the {@link StringInfo}
   */
  public StringInfo getStringInfo();

  /**
   * Sets the {@link StringInfo}.
   * @param string_info the {@link StringInfo}
   */
  public void setStringInfo(StringInfo string_info);

  /**
   * Returns all {@link StringContext}s.
   * @return an array of {@link StringContext}s
   */
  public StringContext [] getStringContexts();

  /**
   * Returns all {@link StringContext}s as a {@link List}
   * @return a {@link List} of {@link StringContext}s
   */
  public List getStringContextsAsList();

  /**
   * Adds the specified {@link StringContext}.
   * @param sc the {@link StringContext} to be added
   */
  public void addStringContext(StringContext sc);

  /**
   * Removes the specified {@link StringContext}.
   * @param sc the {@link StringContext} to be removed
   */
  public void removeStringContext(StringContext sc);

  /**
   * Removes all {@link StringContext}s.
   */
  public void clearStringContexts();

  /**
   * Replaces the {@link StringContext}s with the ones in the specified array.
   * @param scs a {@link StringContext}<code>[]</code>
   */
  public void setStringContexts(StringContext [] scs);

  /**
   * replaces the {@link StringContext}s with the ones in the specified {@link List}.
   * @param scs a {@link List} of {@link StringContext}s
   */
  public void setStringContexts(List scs);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link Atom} fields
   */
  public String getKeyFields();
}