/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   Definition.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Represents a definition of an {@link Atom}.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link Definition}
 * <p><center><img src="Definition.gif"></center>
 * <p>
 * All data in a row of the <code>MRDEF</code> file is represented here.
 * <p>
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface Definition
  extends AtomElement, AttributeElement, Comparable, ConceptElement,
   ContentViewElement, SourceElement, SuppressibleElement {

  /**
   * Returns the definition value (DEF).
   * @return the definition value (DEF).
   */
  public String getDefinition();

  /**
   * Returns the definition value (DEF).
   * This is shorthand for {@link #getDefinition()}.
   * @return the definition value (DEF).
   */
  public String getDef();

  /**
   * Sets the definition value (DEF).
   * @param def the definition value
   */
  public void setDefinition(String def);

  /**
   * Sets the definition value (DEF).
   * This is shorthand for {@link #setDefinition(String)}.
   * @param def the definition value
   */
  public void setDef(String def);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link Definition} fields
   */
  public String getKeyFields();
}