/**************************************************************************
 * Package:	gov.nih.nlm.umls.meta
 * Interface:	IndexEntry.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Represents an entry from an cui index.  The Metathesaurus is released
 * with string and word indexes, and this class represents a single
 * entry from one of those indexes.
 *
 * @author Deborah Shapiro, Brian Carlsen
 */
public interface IndexEntry  {

  //
  // Methods
  //
  /**
   * Returns a {@link String} representation of the CUI.
   * @return a {@link String} representation of the CUI
   */
  public String getCui();

  /**
   * Sets the CUI.
   * @param cui the {@link String} CUI value
   */
  public void setCui(String cui);

  /**
   * Returns a {@link String} representation of the CUI.
   * @return a {@link String} representation of the CUI
   */
  public String getConceptIdentifier();

  /**
   * Sets the CUI.
   * @param cui the {@link String} CUI value
   */
  public void setConceptIdentifier(String cui);

  /**
   * Returns a {@link String} representation of the LUI.
   * @return a {@link String} representation of the LUI
   */
  public String getLui();

  /**
   * Sets the LUI.
   * @param lui the {@link String} LUI value
   */
  public void setLui(String lui );

  /**
   * Returns the term identifier (LUI).
   * @return the LUI
   */
  public String getTermIdentifier();

  /**
   * Sets the term identifier (LUI).
   * @param lui the LUI
   */
  public void setTermIdentifier(String lui);

  /**
   * Returns a {@link String} representation of the SUI.
   * @return a {@link String} representation of the SUI
   */
  public String getSui();

  /**
   * Sets the SUI.
   * @param sui a {@link String} SUI value
   */
  public void setSui(String sui);

  /**
   * Return the string identifier (SUI).
   * @return the SUI
   */
  public String getStringIdentifier();

  /**
   * Sets the string identifier (SUI).
   * @param sui the SUI
   */
  public void setStringIdentifier(String sui);

  /**
   * Returns a {@link String} representation of the language.
   * @return a {@link String} representation of the language
   */
  public String getLat();

  /**
   * Sets the language abbreviation.
   * @param lat the language abbreviation
   */
  public void setLat(String lat);

  /**
   * Returns a {@link String} representation of the language.
   * @return a {@link String} representation of the language
   */
  public String getLanguage();

  /**
   * Sets the language abbreviation.
   * @param lat the language abbreviation
   */
  public void setLanguage(String lat);

  /**
   * Returns the {@link String} that is being indexed.
   * @return the {@link String} that is being indexed
   */
  public String getValue();

  /**
   * Set the {@link String} being indexed
   * @param value the {@link String} being indexed
   */
  public void setValue(String value);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link Atom} fields
   */
  public String getKeyFields();
}

