/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   MetaDescription.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Generically represents metadata having a key, a subkey, a type, and a more
 * detailed description or value.
 *
 * All data in a row of the <code>MRDOC</code> file is represented here.
 *
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface MetaDescription extends Comparable {

  /**
   * Returns the type.
   * @return the type
   */
  public String getType();

  /**
   * Returns the key.
   * @return the key
   */
  public String getKey();

  /**
   * Returns the explain field.
   * @return the explain
   */
  public String getExplain();

  /**
   * Returns the value.
   * @return the value
   */
  public String getValue();

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   *
   * @return a {@link String} composed from key fields
   */
  public String getKeyFields();

}