/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Class:       QualifierFrequency.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Represents a coocurrence qualifier with a frequency.
 * This can be extended to support source-specific things like
 * a "mesh qualifier".
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link QualifierFrequency}
 * <p><center><img src="QualifierFrequency.gif"></center>
 * <p>
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface QualifierFrequency extends Comparable {

  /**
   * Returns the qualifier value.
   * @return the qualifier value
   */
  public String getQualifier();

  /**
   * Sets the qualifier value.
   * @param qual the qualifier value
   */
  public void setQualifier(String qual);

  /**
   * Returns the frequency.
   * @return the frequency
   */
  public int getFrequency();

  /**
   * Sets the frequency;
   * @param freq the frequency
   */
  public void setFrequency(int freq);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link QualifierFrequency} fields
   */
  public String getKeyFields();
}