/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   SemanticType.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

/**
 * Represents a {@link Concept} semantic type.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link SemanticType}
 * <p><center><img src="SemanticType.gif"></center>
 * <p>
 * All data in a row of the <code>MRSTY</code> file is represented here.
 * Note, the STN and TUI fields in <code>MRSTY</code> can be obtained
 * by calling methods on the object returned by {@link #getSemanticType()}.
 * <p>
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface SemanticType
  extends Comparable, ConceptElement, ContentViewElement {

  /**
   * Returns the {@link HierarchicalSemanticType} (STY).
   * @return the {@link HierarchicalSemanticType}
   */
  public HierarchicalSemanticType getSemanticType();

  /**
   * Sets the {@link HierarchicalSemanticType} (STY).
   * @param sty the {@link HierarchicalSemanticType}
   */
  public void setSemanticType(HierarchicalSemanticType sty);

  /**
   * Returns the {@link HierarchicalSemanticType} (STY).
   * This is shorthand for {@link #getSemanticType()}
   * @return the {@link HierarchicalSemanticType}
   */
  public HierarchicalSemanticType getSty();

  /**
   * Sets the {@link HierarchicalSemanticType} (STY).
   * This is shorthand for {@link #setSemanticType(HierarchicalSemanticType)}.
   * @param sty the {@link HierarchicalSemanticType}
   */
  public void setSty(HierarchicalSemanticType sty);

  /**
   * Returns the unique identifier (ATUI).
   * @return the ATUI
   */
  public String getAttributeIdentifier();

  /**
   * Returns the unique identifier (ATUI). This
   * is shorthand for {@link #getAttributeIdentifier()}.
   * @return the ATUI
   */
  public String getAtui();

  /**
   * Sets the unique identifier (ATUI).
   * @param atui the ATUI
   */
  public void setAttributeIdentifier(String atui);

  /**
   * Sets the unique identifier (ATUI).
   * This is shorthand for {@link #setAttributeIdentifier(String)}.
   * @param atui the ATUI
   */
  public void setAtui(String atui);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link SemanticType} fields
   */
  public String getKeyFields();
}