/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   StringAttribute.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

import java.util.List;

/**
 * Represents information about attributes shared at the level of a string identifier.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link StringAttribute}
 * <p><center><img src="StringAttribute.gif"></center>
 * <p>
 * @see TermAttribute
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface StringAttribute extends Comparable {

  /**
   * Returns the {@link TermAttribute} that holds this {@link StringAttribute}.
   * @return the {@link TermAttribute} that holds this {@link StringAttribute}
   */
  public TermAttribute getTermAttribute();

  /**
   * Sets the {@link TermAttribute} that holds this {@link StringAttribute}.
   * @param ta the {@link TermAttribute} that holds this {@link StringAttribute}
   */
  public void setTermAttribute(TermAttribute ta);

  /**
   * Returns the {@link StringInfo}.
   * @return the {@link StringInfo}
   */
  public StringInfo getStringInfo();

  /**
   * Sets the {@link StringInfo}.
   * @param si the {@link StringInfo}
   */
  public void setStringInfo(StringInfo si);

  /**
   * Returns all {@link AttributeContext}s.
   * @return a array of {@link AttributeContext}s
   */
  public AttributeContext [] getAttributeContexts();

  /**
   * Returns all {@link AttributeContext}s as a {@link List}.
   * @return a {@link List} of {@link AttributeContext}s
   */
  public List getAttributeContextsAsList();

  /**
   * Adds the specified {@link AttributeContext}.
   * @param ac the {@link AttributeContext} to be added
   */
  public void addAttributeContext(AttributeContext ac);

  /**
   * Removes the specified {@link AttributeContext}.
   * @param ac the {@link AttributeContext} to be removed
   */
  public void removeAttributeContext(AttributeContext ac);

  /**
   * Removes all {@link AttributeContext}s.
   */
  public void clearAttributeContexts();

  /**
   * Replaces the {@link AttributeContext}s with the ones in the specified array.
   * @param acs a {@link AttributeContext}<code>[]</code>
   */
  public void setAttributeContexts(AttributeContext [] acs);

  /**
   * Replaces the {@link AttributeContext}s with the ones in the specified {@link List}.
   * @param acs a {@link List} of {@link AttributeContext}s
   */
  public void setAttributeContexts(List acs);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link StringAttribute} fields
   */
  public String getKeyFields();
}