/**************************************************************************
 * Package:     gov.nih.nlm.umls.meta
 * Interface:   StringContext.java
 *
 **************************************************************************/
package gov.nih.nlm.umls.meta;

import java.util.List;

/**
 * Represents grouping of {@link SourceContext}s which share
 * the same {@link Source} abbreviation and code.
 * <p>
 * Following is a UML Class diagram showing the neighborhood around {@link StringContext}
 * <p><center><img src="StringContext.gif"></center>
 * <p>
 * @see ContextGroup
 * @author Brian Carlsen, Deborah Shapiro
 */
public interface StringContext
  extends Comparable, AtomElement, SourceElement{

  /**
   * Returns all {@link SourceContext}s.
   * @return an array of {@link SourceContext}s
   */
  public SourceContext[] getSourceContexts();

  /**
   * Returns all {@link SourceContext}s as a {@link List}.
   * @return a List of {@link SourceContext}s
   */
  public List getSourceContextsAsList();

  /**
   * Adds the specified {@link SourceContext}.
   * @param sc the {@link SourceContext} to be added
   */
  public void addSourceContext(SourceContext sc);

  /**
   * Removes the specified {@link SourceContext}.
   * @param sc the {@link SourceContext} to be removed
   */
  public void removeSourceContext(SourceContext sc);

  /**
   * Removes all {@link SourceContext}s.
   */
  public void clearSourceContexts();

  /**
   * Replace the {@link SourceContext}s with the ones in the specified array.
   * @param scs a {@link SourceContext}<code>[]</code>
   */
  public void setSourceContexts(SourceContext [] scs);

  /**
   * Replace the {@link SourceContext}s with the ones in the specified {@link List}.
   * @param scs a {@link List} of {@link SourceContext}s
   */
  public void setSourceContexts(List scs);

  /**
   * Returns the {@link ContextGroup} that holds this {@link StringContext}.
   * @return the {@link ContextGroup} that holds this {@link StringContext}
   */
  public ContextGroup getContextGroup();

  /**
   * Sets the {@link ContextGroup} that holds this {@link StringContext}.
   * @param cg the {@link ContextGroup} that holds this {@link StringContext}
   */
  public void setContextGroup(ContextGroup cg);

  /**
   * Returns a {@link String} key which can be used
   * by equals, compareTo, and hashCode methods.
   * @return a {@link String} composed from key {@link Atom} fields
   */
  public String getKeyFields();
}